/* glpapi/glp_put_soln_info.c */

/*----------------------------------------------------------------------
-- This file is a part of the GLPK package.
--
-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
--                          Department for Applied Informatics,
--                          Moscow Aviation Institute, Moscow, Russia.
--                          All rights reserved.
--
-- This code is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This software is distributed "as is" in the hope that it will be
-- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-- General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
----------------------------------------------------------------------*/

#include "glpapi.h"

/*----------------------------------------------------------------------
-- glp_put_soln_info - store main solution information.
--
-- *Synopsis*
--
-- #include "glpk.h"
-- void glp_put_soln_info(LPI *lp, int bstat, int status, double objv);
--
-- *Description*
--
-- The routine glp_put_soln_info stores main solution information to the
-- problem object.
--
-- The parameters bstat, status, and objv specify basis status, solution
-- status, and value of the objective function, respectively.
--
-- This routine is intended for using by the solver. */

void glp_put_soln_info(LPI *lp, int bstat, int status, double objv)
{     if (!(bstat == '?' || bstat == 'N' || bstat == 'P' ||
            bstat == 'D' || bstat == 'O'))
         fault("glp_put_soln_info: bstat = %d; invalid basis status",
            bstat);
      if (!(status == GLP_UNDEF || status == GLP_OPT ||
            status == GLP_FEAS || status == GLP_INFEAS ||
            status == GLP_NOFEAS || status == GLP_UNBND ||
            status == GLP_INTOPT || status == GLP_INTSOL ||
            status == GLP_DISINT || status == GLP_NOINT))
         fault("glp_put_soln_info: status = %d; invalid solution status"
            , status);
      lp->basis = bstat;
      lp->status = status;
      lp->objval = objv;
      return;
}

/* eof */
